About
Small package that help with custom colloring and sizing up the app
Usage
const like = kcBlackJet;
const gradient = centerLeftRight(kcBlackJet, kcWhiteSnow);
Additional information
where to find more information, how to contribute to the package, how to file issues, what response they can expect from the package authors, and more.
Libraries
- raven
- Support for doing something awesome.